@@ -13,13 +13,6 @@
 # limitations under the License.
 import os
 import sys
-
-__dir__ = os.path.dirname(os.path.abspath(__file__))
-sys.path.append(__dir__)
-sys.path.append(os.path.abspath(os.path.join(__dir__, '../..')))
-
-os.environ["FLAGS_allocator_strategy"] = 'auto_growth'
-
 import cv2
 import time
 import numpy as np
@@ -55,6 +48,7 @@ class TextDetector(object):
             }
         }]
         postprocess_params = {}
+
         if self.det_algorithm == "DB":
             postprocess_params['name'] = 'DBPostProcess'
             postprocess_params["thresh"] = args.det_db_thresh
@@ -92,7 +86,8 @@ class TextDetector(object):
 
         self.preprocess_op = create_operators(pre_process_list)
         self.postprocess_op = build_post_process(postprocess_params)
-        self.session, self.input_names, self.output_names = create_session(args, 'det', logger)
+        self.session, self.input_names, self.output_names = create_session(
+            args, 'det', logger)
 
     def order_points_clockwise(self, pts):
         """
@@ -127,6 +122,7 @@ class TextDetector(object):
     def filter_tag_det_res(self, dt_boxes, image_shape):
         img_height, img_width = image_shape[0:2]
         dt_boxes_new = []
+
         for box in dt_boxes:
             box = self.order_points_clockwise(box)
             box = self.clip_det_res(box, img_height, img_width)
@@ -135,15 +131,18 @@ class TextDetector(object):
             if rect_width <= 3 or rect_height <= 3:
                 continue
             dt_boxes_new.append(box)
+
         dt_boxes = np.array(dt_boxes_new)
         return dt_boxes
 
     def filter_tag_det_res_only_clip(self, dt_boxes, image_shape):
         img_height, img_width = image_shape[0:2]
         dt_boxes_new = []
+
         for box in dt_boxes:
             box = self.clip_det_res(box, img_height, img_width)
             dt_boxes_new.append(box)
+
         dt_boxes = np.array(dt_boxes_new)
         return dt_boxes
 
@@ -155,20 +154,17 @@ class TextDetector(object):
 
         data = transform(data, self.preprocess_op)
         img, shape_list = data
+
         if img is None:
             return None, 0
+
         img = np.expand_dims(img, axis=0)
         shape_list = np.expand_dims(shape_list, axis=0)
         img = img.copy()
-        outputs = self.session.run(self.output_names, {self.input_names[0]: img})
-        # self.input_tensor.copy_from_cpu(img)
-        # self.predictor.run()
-        # outputs = []
-        # for output_tensor in self.output_tensors:
-        #     output = output_tensor.copy_to_cpu()
-        #     outputs.append(output)
-
+        outputs = self.session.run(self.output_names,
+                                   {self.input_names[0]: img})
         preds = {}
+
         if self.det_algorithm == "EAST":
             preds['f_geo'] = outputs[0]
             preds['f_score'] = outputs[1]
@@ -185,14 +181,17 @@ class TextDetector(object):
         #self.predictor.try_shrink_memory()
         post_result = self.postprocess_op(preds, shape_list)
         dt_boxes = post_result[0]['points']
+
         if self.det_algorithm == "SAST" and self.det_sast_polygon:
-            dt_boxes = self.filter_tag_det_res_only_clip(dt_boxes, ori_im.shape)
+            dt_boxes = self.filter_tag_det_res_only_clip(
+                dt_boxes, ori_im.shape)
         else:
             dt_boxes = self.filter_tag_det_res(dt_boxes, ori_im.shape)
 
         et = time.time()
         return dt_boxes, et - st
 
+
 def main(args, image_dir, process_id=0):
     image_file_list = get_image_file_list(image_dir)
     image_file_list = image_file_list[process_id::args.total_process_num]
@@ -203,16 +202,21 @@ def main(args, image_dir, process_id=0):
 
     if not os.path.exists(draw_img_save):
         os.makedirs(draw_img_save)
+
     for image_file in image_file_list:
         img, flag = check_and_read_gif(image_file)
+
         if not flag:
             img = cv2.imread(image_file)
+
         if img is None:
             logger.info("error in loading image:{}".format(image_file))
             continue
+
         st = time.time()
         dt_boxes, _ = text_detector(img)
         elapse = time.time() - st
+
         if count > 0:
             total_time += elapse
         count += 1
@@ -225,6 +229,7 @@ def main(args, image_dir, process_id=0):
         cv2.imwrite(img_path, src_im)
         logger.info("The visualized image saved in {}".format(img_path))
 
+
 if __name__ == "__main__":
     parser = init_args()
     main(parse_args(parser))
